#property copyright "Copyright 2017, TheXpert"
#property link      "http://trend-lab.blogspot.com/"

// magic number needed for filtering orders opened by certain EA
extern int        Magic             =  13579;
// lots size of opening orders. If 0 it is counted automatically
extern double     TradeLots         =  0.1;
// risk for automatic lots size counting
extern double     RiskPercentage    =  0;
// maximum acceptable slippage for the price
extern int        Slippage          =  30;
extern int        Loss              =  1000;
extern int        Differ            =  30;

string symbol;

double GetLotsToBid(double risk)
{
   if (TradeLots > 0) return (TradeLots);
   if (risk < 0) risk = 0;
   
   double margin  = MarketInfo(Symbol(), MODE_MARGINREQUIRED);
   double minLot  = MarketInfo(Symbol(), MODE_MINLOT);
   double maxLot  = MarketInfo(Symbol(), MODE_MAXLOT);
   double step    = MarketInfo(Symbol(), MODE_LOTSTEP);
   double account = AccountEquity();
   
   double percentage = account*risk/100;
   
   if (margin*step == 0) return(minLot);
   double lots = MathRound(percentage/margin/step)*step;
   
   if(lots < minLot)
   {
      lots = minLot;
   }
   
   if(lots > maxLot)
   {
      lots = maxLot;
   }

   return (lots);
}

void Check()
{
   bool buy = false;
   bool sell = false;
   double sells_rate = iCustom(Symbol(), Period(), "Market/OandaX Ratio History", 0, 0, false, "", "AUTO", true, 0, 1);
   
   if (sells_rate != EMPTY_VALUE)
   {
      if (sells_rate > 50.0 + Differ / 2.0) buy = true;
      if (sells_rate < 50.0 - Differ / 2.0) sell = true;
   }
   
   int b = 0;
   int s = 0;
   for(int i = OrdersTotal() -1; i >= 0; i--)
   {
      if(!OrderSelect(i, SELECT_BY_POS)) continue;
      if(OrderSymbol() != Symbol()) continue;
      if(OrderMagicNumber() != Magic) continue;
      
      RefreshRates();
      switch(OrderType())
      {
         case OP_BUY:
            {
               b++;
               if (sell || (sells_rate > 50 && sells_rate != EMPTY_VALUE && !buy))
               {
                  OrderClose(OrderTicket(), OrderLots(), OrderClosePrice(), Slippage);
                  Print("1 sells_rate = ", sells_rate);
               }
            }
            break;
         case OP_SELL:
            {
               s++;
               if (buy || (sells_rate < 50 && sells_rate != EMPTY_VALUE && !sell))
               {
                  OrderClose(OrderTicket(), OrderLots(), OrderClosePrice(), Slippage);
                  Print("2 sells_rate = ", sells_rate);
               }
            }
            break;
      }
   }
   
   if (buy)
   {
      RefreshRates();
      Print("3 sells_rate = ", sells_rate);
      OrderSend(Symbol(), OP_BUY, GetLotsToBid(RiskPercentage), Ask, Slippage, Ask - Loss*Point, 0, NULL, Magic);
   }
   
   if (sell)
   {
      RefreshRates();
      Print("4 sells_rate = ", sells_rate);
      OrderSend(Symbol(), OP_SELL, GetLotsToBid(RiskPercentage), Bid, Slippage, Bid + Loss*Point, 0, NULL, Magic);
   }
}

void init()
{
   symbol = Symbol();
}

datetime LastTime = 0;

int start()
{
   if (LastTime < Time[0])
   {
      LastTime = Time[0];
      Check();
   }

   return(0);
}